@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 
 use 5.008;
 use strict;
@@ -8,63 +8,16 @@ use File::Basename ();
 use File::Spec;
 use Getopt::Long;
 use POSIX;
-use Sys::Hostname;
-# [LH] 2013-08-04:  Added Fcntl for better pidfile locking.  [RT81914]
-use Fcntl qw(:DEFAULT :flock);
 
 use Error qw(:try);
+use Sys::Hostname;
+use TheSchwartz;
 
 use Helios;
 use Helios::Error;
 use Helios::LogEntry::Levels qw(:all);
-use Helios::TheSchwartz;
-use Helios::Config;
 
-our $VERSION = '2.601_3610';
-
-# FILE CHANGE HISTORY
-# [2012-01-08]: Added a check to try to prevent loading code outside of @INC.
-# [2012-01-09]: Modified check to prevent loading code outside of @INC.
-# [2012-03-25]: Added code to prevent a worker process from changing into a  
-# daemon due to odd (and uncommon) database connection instability.
-# [2012-03-27]: Changed $DEFAULTS{ZERO_SLEEP_INTERVAL} to 10.  Added code to 
-# add "registration_interval" as a configuration parameter.  Added 
-# $DEFAULTS{REGISTRATION_INTERVAL} and set to 60.  Changed 
-# $REGISTRATION_INTERVAL to 60.
-# [2012-04-01]: Changed service module loaded notification to report version 
-# only if the module has a $VERSION set.  Changed service initialization to use
-# the prep() method instead of getConfigFromIni() and getConfigFromDb() to 
-# ensure proper initialization of loggers and Data::ObjectDriver database 
-# connection.
-# [2012-05-20]: Removed old commented out calls to getConfigFrom*(), 
-# clean_shutdown(), and logMsg() (logging a HALT message).  Removed 2 empty
-# comments.
-# [LH] [2012-07-11]: Switched from using TheSchwartz to using 
-# Helios::TheSchwartz.  Added WORKER_BLITZ_FACTOR feature to launch workers 
-# faster when there are less than MAX_WORKERS jobs available.  Stopped closing
-# STDOUT, STDIN, and STDERR when helios.pl daemonizes because it was causing
-# problems with some services.
-# [LH] [2012-07-15]: Added to use Helios::Config, and changed configuration 
-# update code to use Helios::Config instead of getConfigFromDb().  Added 
-# debugging messages for ZERO_SLEEP_INTERVAL and REGISTRATION_INTERVAL.
-# [LH] [2012-07-26]: Changed "worker_blitz_factor" config param to 
-# "WORKER_BLITZ_FACTOR".  Added new code to better handle database connections
-# after a fork() so worker processes do not share or disconnect the daemon's 
-# connections.
-# [LH] [2012-07-29]: Added DOUBLE_CLUTCH_INTERVAL config parameter to control 
-# WORKER_MAX_TTL functionality better than ZERO_LAUNCH_INTERVAL.  Updated 
-# copyright info.  
-# [LH] [2012-09-05]: Changed DOUBLE_CLUTCH_INTERVAL to 
-# WORKER_MAX_TTL_WAIT_INTERVAL.
-# [LH] [2012-09-28]: Removed old commented out code.
-# [LH] [2012-10-12]: Replaced code attempting to prevent loading of modules
-# outside of @INC with new require_module() function.
-# [LH] [2012-12-11]: Added code to apply WORKER_MAX_TTL after registration in 
-# daemon main loop.  [RT81709]
-# [LH] [2013-08-04]: Implemented new PID file locking scheme to fix [RT81914]. 
-# Replaced write_pid_file() and mostly rewrote running_process_check() to 
-# prevent a PID file race condition.  
-# [LH] [2013-08-19]: Added comments for clarification of fix for [RT81914].
+our $VERSION = '2.22';
 
 =head1 NAME
 
@@ -273,10 +226,7 @@ our %DEFAULTS = (
     PID_PATH => File::Spec->catfile(File::Spec->rootdir, 'var', 'run', 'helios'),
     MASTER_LAUNCH_INTERVAL => 1,
     ZERO_LAUNCH_INTERVAL => 10,
-    ZERO_SLEEP_INTERVAL => 10,
-    REGISTRATION_INTERVAL => 60,
-    WORKER_BLITZ_FACTOR => 1,
-    WORKER_MAX_TTL_WAIT_INTERVAL => 20
+    ZERO_SLEEP_INTERVAL => 30
 );
 our $CLEAN_SHUTDOWN = 1;				# used to determine if we should remove the PID file or not (at least for now)
 
@@ -287,26 +237,16 @@ our $MASTER_LAUNCH_INTERVAL;
 our $ZERO_LAUNCH_INTERVAL;
 
 our $START_TIME = time();				# used to measure uptime from the registry table
-our $REGISTRATION_INTERVAL = 60;		# used to periodically register daemon in database
+our $REGISTRATION_INTERVAL = 300;		# used to periodically register daemon in database
 our $REGISTRATION_LAST = 0;
 
 our $PID_FILE;							# globally accessible PID file location
-# [LH] 2013-08-04:  Added $PID_FILE_H as a filehandle for better pidfile locking.  [RT81914]
-our $PID_FILE_H; 						# globally accessible PID file handle
 our $SAFE_MODE_DELAY = 45;				# SAFE MODE support; number of secs to wait
 our $SAFE_MODE_RETRIES = 5;				# SAFE MODE support; number of times to retry 
 
 our $ZERO_SLEEP_INTERVAL;				# to reduce needless checking of the database
 our $ZERO_SLEEP_LOG_INTERVAL = 3600;	# to reduce needless log msgs in log_tb
 our $ZERO_SLEEP_LOG_LAST = 0;
-our $WORKER_MAX_TTL_WAIT_INTERVAL = 20;		# for WORKER_MAX_TTL functionality
-
-our $WORKER_PROCESS = 0;				# used to indicate process has become a worker process
-										# this is used in addition to getppid() to prevent workers
-										# from becoming daemons in case of database instability
-
-our $WORKER_BLITZ_FACTOR = 1;			# used to determine how many workers to launch
-our $HELIOS_DB_CONN;					# database handle to help with DBI+forking issues
 
 # print help if asked
 if ( !defined($CLASS) || ($CLASS eq '--help') || ($CLASS eq '-h') ) {
@@ -320,26 +260,12 @@ print "Helios ",$Helios::VERSION,"\n";
 print "helios.pl Service Daemon version $VERSION\n";
 # --version support
 if ( $CLASS eq '--version') { exit(); }
-#if ( $worker_class !~ /^[A-Za-z]([A-Za-z0-9_\-]|:{2})*[A-Za-z0-9_\-]$/ ) {
-#	print "Sorry, requested name is invalid: $worker_class\n";
-#	exit(1);
-#}
 print "Attempting to load $worker_class...\n"; 
-#unless ( $worker_class->can('new') ) {
-#        eval "require $worker_class";
-#        die $@ if $@;
-#}
-unless ( $worker_class ) {
-	print "You must specify the module name of a Helios service.\n";
-	exit(1);
-}
-require_module($worker_class);
-
-if ( defined($worker_class->VERSION) ) {
-	print $worker_class, ' ', $worker_class->VERSION," loaded.\n";
-} else{
-	print $worker_class," loaded.\n";
+unless ( $worker_class->can('new') ) {
+        eval "require $worker_class";
+        die $@ if $@;
 }
+print $worker_class, ' ', $worker_class->VERSION," loaded.\n";
 if ($DEBUG_MODE) { print "Debug Mode enabled.\n"; }
 
 # instantiate a worker to access the necessary settings
@@ -353,7 +279,8 @@ if ( defined($HELIOS_INI) ) {
 $worker->setJobType($worker_class);
 $worker->debug($DEBUG_MODE);
 eval {
-	$worker->prep();
+        $worker->getConfigFromIni();
+        $worker->getConfigFromDb();
 };
 if ($@) {
         die("FAILED to get configuration: $@");
@@ -383,32 +310,10 @@ if ( defined($params->{zero_sleep_interval}) ) {
 } else {
 	$ZERO_SLEEP_INTERVAL = $DEFAULTS{ZERO_SLEEP_INTERVAL};
 }
-if ( defined($params->{registration_interval}) ) {
-	$REGISTRATION_INTERVAL = $params->{registration_interval};
-} else {
-	$REGISTRATION_INTERVAL = $DEFAULTS{REGISTRATION_INTERVAL};
-}
-if ( defined($params->{WORKER_BLITZ_FACTOR}) ) {
-	$WORKER_BLITZ_FACTOR = $params->{WORKER_BLITZ_FACTOR};
-} else {
-	$WORKER_BLITZ_FACTOR = $DEFAULTS{WORKER_BLITZ_FACTOR};
-}
-if ( defined($params->{WORKER_MAX_TTL_WAIT_INTERVAL}) ) {
-	$WORKER_MAX_TTL_WAIT_INTERVAL = $params->{WORKER_MAX_TTL_WAIT_INTERVAL};
-} else {
-	$WORKER_MAX_TTL_WAIT_INTERVAL = $DEFAULTS{WORKER_MAX_TTL_WAIT_INTERVAL};	
-}
-
-# make a globally accessible database handle 
-# to make it easier to clean up CachedKids after a fork()
-$HELIOS_DB_CONN = $worker->dbConnect();
 
 if ($DEBUG_MODE) { 
 	print "MASTER LAUNCH INTERVAL: $MASTER_LAUNCH_INTERVAL\n"; 
 	print "ZERO LAUNCH INTERVAL: $ZERO_LAUNCH_INTERVAL\n"; 
-	print "ZERO SLEEP_INTERVAL: $ZERO_SLEEP_INTERVAL\n";	
-	print "REGISTRATION_INTERVAL: $REGISTRATION_INTERVAL\n";
-	print "WORKER BLITZ FACTOR: $WORKER_BLITZ_FACTOR\n";
 }
 
 my %workers;
@@ -435,7 +340,8 @@ my $times_sleeping = 0;
 # daemonize and launch the main loop
 if ( defined($ARGV[0]) && lc($ARGV[0]) eq '--clear-halt' ) {
 	clear_halt();
-	$worker->prep();
+	$worker->getConfigFromIni();
+	$worker->getConfigFromDb();
 	$params = $worker->getConfig();
 }
 if ( defined($params->{HALT}) ) {
@@ -518,19 +424,15 @@ MAIN_LOOP:{
 		
 				# recheck db parameters
 				$params = undef;
-				$params = Helios::Config->parseConfig();
-				
+				$worker->getConfigFromDb();	
+				$params = $worker->getConfig();
+
+
 				# DAEMON REGISTRATION
 				# every $REGISTRATION_INTERVAL seconds, (re)register this daemon in the database
 				if ( ($REGISTRATION_LAST + $REGISTRATION_INTERVAL) < time() ) {
 					register();
 					$REGISTRATION_LAST = time();
-					# [LH] 2012-12-11: Copied WORKER_MAX_TTL/double_clutch() call from HOLD code below 
-					# to enable WORKER_MAX_TTL in Normal Mode as well as Hold Mode.  [RT81709]
-					if ( defined($params->{WORKER_MAX_TTL}) && $params->{WORKER_MAX_TTL} > 0 
-					       && scalar(keys %workers) ) {
-					    double_clutch();
-					}
 				}
 		
 				# HOLDING JOB PROCESSING
@@ -542,7 +444,7 @@ MAIN_LOOP:{
 					}
 					if ($DEBUG_MODE) { print "$0 $worker_class HOLDING\n"; }
 					sleep 60; 
-					# after the first cycle through HOLD, the workers had BETTER be dead 
+					# after the first cycle through HOLD, the workers had BETTER be dead  #[]?
 					if ( defined($params->{WORKER_MAX_TTL}) && $params->{WORKER_MAX_TTL} > 0 
 					       && scalar(keys %workers) ) {
 					    double_clutch();
@@ -566,7 +468,7 @@ MAIN_LOOP:{
 					$worker->logMsg(LOG_DEBUG, $waiting_jobs . " waiting " . $worker_class . " jobs.");
 				}
 				unless ( $waiting_jobs ) {
-						$times_sleeping++;	  
+						$times_sleeping++;	  #[]
 						# only log the "0 workers running, 0 workers in queue.  SLEEPING" message every $ZERO_SLEEP_LOG_INTERVAL seconds
 						# (necessary to prevent overwhelming database logging with messages we don't care about)
 						if ( ($running_workers == 0) && (($ZERO_SLEEP_LOG_LAST + $ZERO_SLEEP_LOG_INTERVAL ) < time()) ) {
@@ -585,11 +487,9 @@ MAIN_LOOP:{
 				# if we've got to this part of the loop, we have jobs that need workers to launch
 				# (though we still may not do it if we've already reached our limit)
 				my $workers_to_launch = $max_workers - $running_workers;
-				# if the number of waiting jobs is less than (max workers * worker blitz factor)
+				# if the number of waiting jobs is less than max workers
 				# then only launch one worker to reduce worker contention
-				# refresh worker blitz factor, then determine if we blitz or not
-				$WORKER_BLITZ_FACTOR = $params->{WORKER_BLITZ_FACTOR} ? $params->{WORKER_BLITZ_FACTOR} : $DEFAULTS{WORKER_BLITZ_FACTOR};
-				if ( ($workers_to_launch > 0) && ($waiting_jobs < ($max_workers * $WORKER_BLITZ_FACTOR ) ) ) {
+				if ( ($workers_to_launch > 0) && ($waiting_jobs < $max_workers) ) {
 					$workers_to_launch = 1;
 				}
 				$worker->logMsg(LOG_NOTICE, "$waiting_jobs jobs waiting; $running_workers workers running; launching $workers_to_launch workers");
@@ -603,26 +503,6 @@ MAIN_LOOP:{
 										sleep 1;
 								} elsif (defined $pid) { # $pid is zero here if defined
 										# I'm the child!
-										$WORKER_PROCESS = 1;
-										
-# BEGIN CODE Copyright (C) 2012 by Logical Helion, LLC.
-										# BEFORE WE LAUNCH THE WORKER,
-										# clean up the database connections from the parent
-										# we'll set InactiveDestroy on the existing connections
-										# then we'll clear them, leaving the parent connections
-										# free of any influence of the children
-										# NOTE:  with DBI >= 1.614, all we'd have to do is
-										# set AutoInactiveDestroy on all the connections
-										# but to support the DBI (1.52) bundled with RHEL & CentOS 5,
-										# we have to make do with what we have
-										my $ck = $HELIOS_DB_CONN->{Driver}->{CachedKids};
-										foreach (keys %$ck) {
-											$ck->{$_}->{InactiveDestroy} = 1;
-										}
-										%$ck = ();
-# END CODE Copyright (C) 2012 by Logical Helion, LLC.
-
-										# NOW, launch the worker
 										launch_worker();
 							} elsif ($! == EAGAIN) {
 								# EAGAIN is the supposedly recoverable fork error
@@ -666,11 +546,6 @@ MAIN_LOOP:{
 		
 	} otherwise {
 		my $e = shift;
-		# if we're a worker process and we ended up here
-		# it's a fluke caused by the database instability
-		# we have to bail out and hope the service daemon survives
-		# since the default logger will also be affected by this error, we can't log anything either :(
-		if ( (getppid() > 1) || ($WORKER_PROCESS == 1) ) { exit(42); }
 		if ($DEBUG_MODE) { 
 			print "EXCEPTION THROWN: ",$e->text,"\n"; 
 			print "ATTEMPTING TO RECONNECT...\n";
@@ -713,6 +588,7 @@ if ($CLEAN_SHUTDOWN) {
 	# if we're cleanly shutting down (we were told to via helios_params_tb)
 	# unregister from Helios database
 	# remove our PID
+#[]	clean_shutdown();
     terminator();
 } else {
 	# if we've had a db error, this will throw an exception when it tries to log to the database
@@ -720,6 +596,7 @@ if ($CLEAN_SHUTDOWN) {
 	$worker->logMsg(LOG_ERR,"$0 $worker_class HALTED on error: ".$worker->errstr);
 }
 
+#[] $worker->logMsg(LOG_NOTICE, "$0 $worker_class HALTED");
 if ($DEBUG_MODE) { print "$0 $worker_class HALTED!\n"; }
 
 exit();
@@ -749,7 +626,6 @@ sub daemonize {
     # but I'll put them in for perlipc's sake anyway
     open STDIN, '/dev/null';
     open STDOUT, '>/dev/null';
-    open STDERR, '>/dev/null';
     
 	my $pid = fork;   
 	# make sure fork was successful
@@ -774,10 +650,9 @@ sub daemonize {
 	# session and making our own process group
 	# as well as closing any standard open filehandles.
 	POSIX::setsid();
-#[] I may have changed religions on this one
-#	close (STDIN); 
-#	close (STDOUT); 
-#	close (STDERR);
+	close (STDIN); 
+	close (STDOUT); 
+	close (STDERR);
 
 	# set up signal handling in main process 
 }
@@ -789,22 +664,19 @@ The double_clutch() function implements the WORKER_MAX_TTL functionality.  If
 the WORKER_MAX_TTL parameter is set for a service, the service daemon 
 periodically calls double_clutch() to check the workers and clean up any that 
 have run too long.  The double_clutch() function waits a certain amount of time 
-(WORKER_MAX_TTL_WAIT_INTERVAL secs), then checks the amount of time each of the 
+(zero_launch_interval x2 secs), then checks the amount of time each of the 
 running workers has been active.  If a worker has been running longer than the 
 service's WORKER_MAX_TTL, the worker is killed (by sending it a SIGKILL signal).
 
 =cut
 
 sub double_clutch {
-# BEGIN CODE Copyright (C) 2012 by Logical Helion, LLC.
-	# check each running worker to see if it has been running too long
-	# (too long:  WORKER_MAX_TTL seconds + WORKER_MAX_TTL_WAIT_INTERVAL "fudge factor")
-# END CODE Copyright (C) 2012 by Logical Helion, LLC.
+    # sleep $ZERO_LAUNCH_INTERVAL secs before we double check on workers
+    sleep $ZERO_LAUNCH_INTERVAL;
+    sleep $ZERO_LAUNCH_INTERVAL;
     foreach my $pid (keys %workers) {
-# BEGIN CODE Copyright (C) 2012 by Logical Helion, LLC.
-        my $time_to_die = $workers{$pid} + $params->{WORKER_MAX_TTL} + $WORKER_MAX_TTL_WAIT_INTERVAL;
-# END CODE Copyright (C) 2012 by Logical Helion, LLC.
-        if ( time() > $time_to_die ) {
+        my $time_of_death = $workers{$pid} + $params->{WORKER_MAX_TTL};
+        if ( time() > $time_of_death ) {
             kill 9, $pid;
             delete $workers{$pid};
             $worker->logMsg(LOG_ERR, "Killed process $pid (exceeded WORKER_MAX_TTL)");
@@ -830,7 +702,7 @@ sub launch_worker {
     # just in case this would cause a problem in worker process
     $SIG{CHLD} = 'DEFAULT';
     $SIG{TERM} = 'DEFAULT';
-	my $client = Helios::TheSchwartz->new(databases => $DATABASES_INFO);
+	my $client = TheSchwartz->new(databases => $DATABASES_INFO);
 	$client->can_do($worker_class);
 	my $return;
 	if ( defined($params->{OVERDRIVE}) && $params->{OVERDRIVE} == 1 ) {
@@ -971,9 +843,6 @@ sub terminator {
 }
 
 
-# [LH] 2013-08-04:  Added 2nd paragraph to write_pid_file() documentation to 
-# help explain how new running_process_check()/write_pid_file() works.
-
 =head1 PID FILE FUNCTIONS
 
 =head2 write_pid_file($pid_path)
@@ -984,33 +853,25 @@ replaced by underscores.  For example, the PID file for a service class named
 'SearchIndex::LoadTestWorker' will be named "searchindex__loadtestworker.pid".  To change the 
 location where the PID file is created, set the pid_path option in helios.ini.
 
-The running_process_check() function should be run before this function to 
-exclusively lock the PID file.
-
 =cut
 
 sub write_pid_file {
-# BEGIN CODE Copyright (C) 2013 Logical Helion, LLC.	
-	# [LH] 2013-08-04:  Rewrote write_pid_file() to take advantage of the 
-	# exclusive lock on the pidfile created by running_process_check().
-	# [RT81914]
+	my $pid_path = shift;
+	my $fh;
+	# Determine where to put the PID file
+	unless (defined($pid_path) ) {
+		$pid_path = $DEFAULTS{PID_PATH};
+	}
 
-	# Rewind the PID file handle opened by running_process_check(),
-	# write our own PID in the file, and 
-	# signal to the calling routine it's OK to finish start up.
-	seek($PID_FILE_H, 0, 0) or do {
-		$worker->errstr("Cannot rewind $PID_FILE: ".$!);
-		close($PID_FILE_H);
-		return 0;
-	};
-	print $PID_FILE_H $$,"\n";
-	truncate($PID_FILE_H, tell($PID_FILE_H)) or do {
-		$worker->errstr("Cannot truncate $PID_FILE after writing PID: ".$!);
-		close($PID_FILE_H);
-		return 0;
-	};
-	close($PID_FILE_H);
-# END CODE Copyright (C) 2013 Logical Helion, LLC
+	# Determine PID filename
+	my $filename = lc($worker_class);
+	$filename =~ s/\:/\_/g;
+	$PID_FILE = File::Spec->catfile($pid_path, $filename.'.pid');
+	if ($DEBUG_MODE) { print "Writing pid file $PID_FILE\n";	}
+	
+	open $fh, ">", $PID_FILE or do { $worker->errstr("Cannot write PID file $PID_FILE: ".$!); return undef; };
+	print $fh $$;
+	close $fh;
 
 	return 1;
 }
@@ -1033,8 +894,6 @@ sub remove_pid_file {
 }
 
 
-# [LH] 2013-08-04: Added 2nd paragraph below to explain how new running_process_check() works.
-
 =head2 running_process_check($pid_path)
 
 Given the pid_path, check to see if a $pid_file for the loaded service class exists and, if it does,
@@ -1042,11 +901,6 @@ check to see if that process is still running.  If the file doesn't exist or it
 running, this function returns 0.  If the process is still running, record the error and return the 
 running process's pid to signal that service startup should halt. 
 
-If the PID file does not exist, running_process_check() creates it.  The PID 
-file is then exclusively locked to prevent other daemons for the same service 
-from writing to it.  This helps ensure multiple Helios daemons for same 
-service will not start up at the same time.
-
 =cut
 
 sub running_process_check {
@@ -1063,37 +917,15 @@ sub running_process_check {
 	# check if this file exists
 	# if it does, check if that process is still running
 	# bail if it is
-# BEGIN CODE Copyright (C) 2013 Logical Helion, LLC.
-	# [LH] 2013-08-04:  Rewrote this piece of running_process_check() to put 
-	# an exclusive lock on the pidfile (also creating it if it doesn't exist).
-	# Also switched to using the relatively portable Perl kill() instead of 
-	# grep-ing shell output to determine whether the process in the pidfile
-	# is still running.  [RT81914]
-	sysopen($PID_FILE_H, $PID_FILE, O_RDWR | O_CREAT) or do {
-		$worker->errstr("Cannot open $PID_FILE: ".$!);
-		return 1;		
-	};
-	flock($PID_FILE_H, LOCK_EX | LOCK_NB) or do {
-		$worker->errstr("Cannot lock $PID_FILE (another daemon already starting for this service?): ".$!);
-		close($PID_FILE_H);
-		return 1;
-	};
-	
-	my $pid_in_file = <$PID_FILE_H>;
-	chomp $pid_in_file if defined($pid_in_file);
-	# if there's an actual, valid pid in the file, 
-	# check to see if that process is still running
-	if ( defined($pid_in_file) && $pid_in_file !~ /\D/ && $pid_in_file > 1) {
-		my $proc_count = kill 0, $pid_in_file;
-		if ($proc_count > 0) {
-			$worker->errstr($worker->getJobType()." service daemon already running (process ".$pid_in_file.").");
-			close($PID_FILE_H);
-			return $pid_in_file;
-		}
+	if (-r $PID_FILE) {
+		my $pid = `cat $PID_FILE`;
+		my $pinfo = `ps -p $pid|wc -l`;
+		# is this process still running?
+		if ($pinfo > 1) {
+			$worker->errstr($worker->getJobType()." service daemon already running (process ".$pid.").");
+			return $pid;
+		} 
 	}
-	
-# END CODE Copyright (C) 2013 Logical Helion, LLC.
-	
 	return 0;
 }
 
@@ -1210,37 +1042,6 @@ sub clear_halt {
 	return 1;	
 }
 
-# BEGIN CODE Copyright (C) 2012 by Logical Helion, LLC.
-# [LH] 2012-10-12: Added this method to more securely load module code at runtime.
-
-sub require_module {
-	my $service_class = shift;
-	
-	if ( $service_class !~ /^[A-Za-z]([A-Za-z0-9_\-]|:{2})*[A-Za-z0-9_\-]$/ ) {
-		print STDERR "Sorry, requested name is invalid: $service_class\n";
-		exit(1);
-	}
-	unless ( $service_class->can('new') ) {
-        eval {
-        	my $class_file = $service_class;
-        	$class_file .= '.pm';
-        	$class_file =~ s/::/\//g;
-			require $class_file;
-			1;
-		} or do {
-			my $E = $@;
-			print STDERR "Perl module $service_class could not be loaded: $E\n";
-			exit(1);			
-		};
-	}
-	unless ($service_class->isa('Helios::Service')) {
-		print STDERR "$service_class is not a subclass of Helios::Service.\n";
-		exit(1);
-	}
-	return 1;
-}
-
-# END CODE Copyright (C) 2012 by Logical Helion, LLC.
 
 
 =head1 SEE ALSO
@@ -1255,9 +1056,6 @@ Andrew Johnson, E<lt>lajandy at cpan dotorgE<gt>
 
 Copyright (C) 2007-9 by CEB Toolbox, Inc.
 
-Portions of this software, where noted, are
-Copyright (C) 2012-2013 by Logical Helion, LLC.
-
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.0 or,
 at your option, any later version of Perl 5 you may have available.
