@@ -1,23 +1,16 @@
 package Helios::Error::FatalNoRetry;
 
-use 5.008;
-use strict;
-use warnings;
-use base qw(Helios::Error::BaseError);
+use base qw(Error::Simple);
 
-our $VERSION = '2.811_4150';
-
-# 2011-12-18:  Changed base class from Error::Simple to Helios::Error::BaseError.
-# [2014-10-10] [LH]: Added 5.008, strict, and warnings pragmas for Kwalitee 
-# ratings.
+our $VERSION = '1.20';
 
 1;
 __END__;
 
 =head1 NAME
 
-Helios::Error::FatalNoRetry - fatal exception class for Helios indicating a 
-job failed and the error was so serious the job should not be reattempted.
+Helios::Error::FatalNoRetry - fatal exception class for Helios job processing system; implies 
+a job failed and the error was so serious the job should not be reattempted.
 
 =head1 SYNOPSIS
 
