@@ -1,23 +1,16 @@
 package Helios::Error::Warning;
 
-use 5.008;
-use strict;
-use warnings;
-use base qw(Helios::Error::BaseError);
+use base qw(Error::Simple);
 
-our $VERSION = '2.811_4150';
-
-# 2011-12-18:  Changed base class from Error::Simple to Helios::Error::BaseError.
-# [2014-10-10] [LH]: Added 5.008, strict, and warnings pragmas for Kwalitee 
-# ratings.
+our $VERSION = '1.20';
 
 1;
 __END__;
 
 =head1 NAME
 
-Helios::Error::Warning -  exception class for Helios indicating a job was
-successful but it encountered errors during processing
+Helios::Error::Warning -  exception class for Helios job processing system; implies the job was
+successful but there was something that should be logged as an error
 
 =head1 SYNOPSIS
 
